function [fg, nodemap] = bnetToFactorGraph(bnet)
% function to convert a Bayesian Network in BNT format
% to a factor graph.  Also returned is a node mapping 
% of the form vector->index that contains the relationship
% between nodes from the bnet that form a factor in the 
% factor graph (in the general case this is a vector->index
% mapping, but in this case its just a index->index mapping).
  
  % topological order enforced by mk_bnet
  order = bnet.order;
  N = length(order);
  vars = 1:N;
  factors = cell(1,N);
  nodemap = cell(1,N);
  nodeSizes = zeros(1,N);
  for (i = 1:N) 
    % a factor is a CPT over the node and its parents
    parents = bnet.parents{order(i)};
    scope = [parents order(i)];
    sizes = [bnet.node_sizes(parents) bnet.node_sizes(order(i))];
    nodeSizes(order(i)) = bnet.node_sizes(order(i));
    % needs to be 'flat' for factorMake
    T = reshape(get_field(bnet.CPD{order(i)}, 'cpt'), [1 prod(sizes)]);
    
    % create the factor
    factors{order(i)} = factorMake(scope, sizes, T);
    factors{order(i)} = factorSortScope(factors{order(i)});
    nodemap{order(i)} = [[order(i)], order(i)];			  
  end;
  fg.factors = factors;
  fg.vars = vars;
  fg.sizes = nodeSizes;
  
