function Fbig = factorExtendScope(Fsmall, bigscope, bigsz)
% factorExtendScope Extend scope of factor by replicating dimensions
% function Fbig = factorExtendScope(Fsmall, bigscope, bigsz)
%
% e.g., if Fsmall has scope [1 3] and size [2 2],
% and bigscope = [1 2 3 4], bigsz = [2 2 2 2], we construct
% Fbig(X1,X2,X3,X4) = Fsmall(X1, X3) by replicating along X2, X4 as follows:
%   F = reshape(Fsmall, [2 1 2 1]);
%   F = repmat(F,       [1 2 1 2]);
%   Fbig = factorMake(bigscope, bigsz, F)


if isequal(Fsmall.scope, bigscope) | (isempty(Fsmall.scope) & isempty(bigscope))
  Fbig = Fsmall;
  return;
end
map = match(Fsmall.scope, bigscope);
reshapeSz = ones(1, length(bigscope));
reshapeSz(map) = Fsmall.sizes;
if length(reshapeSz) > 1
  T = reshape(Fsmall.T, reshapeSz);
else
  T = Fsmall.T;
end
repmatSz = bigsz;
repmatSz(map) = 1;
if length(repmatSz)==1
  T = repmat(T, repmatSz, 1);
else
  T = repmat(T, repmatSz);
end

Fbig = factorMake(bigscope, bigsz, T);

