function F = factorMake(scope, sizes, T)
% FACTORMAKE Construct a tabular factor
% function F = factorMake(scope, sizes, T)
% 
% T is an optional array of values; if omitted, we initialize to all 1s.
% e.g., F = factorMake([5 2 4], [2 1 3]) makes a factor over (X5, X2, X4) where
% X5 has 2 values, X2 has 1 value, and X4 has 3 values, (so F.T is 2x1x3 array).


if nargin < 3
  if length(sizes)==0 % a constant
    T = 1;
  elseif length(sizes)==1
    T = ones(sizes, 1);
  else
    T = ones(sizes); 
  end
end

F.scope = scope;
F.sizes = sizes;
if length(sizes) > 1
  F.T = reshape(T, sizes);
else
  F.T = T(:);
end
